@@ -13,22 +13,27 @@
 
 @implementation BoolNode
 
--setBoolFunc: (int) bf { // set the boolean function type for the element
+- setBoolFunc: (int)bf 
+{ // set the boolean function type for the element
   function = bf;
   return self;
 }
 // offer two methods to add a link 
 // one via the actual node, the other via an integer index
 
--makeLinkFrom: aNode {           // create a link to the current node using the element itself
+// create a link to the current node using the element itself
+- makeLinkFrom: aNode 
+{           
   [super makeLinkFrom: aNode];
   return self;
 }
 
--makeLinkFromWithInt: (int) aNumber {   // create a link to the current node using an integer index
+// create a link to the current node using an integer index
+- makeLinkFromWithInt: (int)aNumber 
+{  
    id entityList, entity, index, aNode;
 
-   entityList = [boolNet getNodeList];   // get the list of nodes in the Boolean network
+   entityList = [boolNet getNodeList]; // get the list of nodes
 
    // need to search the entity list to find the correct node to make link to
 
@@ -36,21 +41,21 @@
    while ( (entity = [index next]) ) {
      if ([entity getInstanceNumber] == aNumber) {
        aNode = entity;
-       //        if (aNode == self) {             // check to see if the link is to self
-       //  	[nodeItem setColor: "green"];     // if so, set the colour of the node
-       //        }
        [self makeLinkFrom: aNode];     // found it! - make a link to it!
      }
-     else {   // couldn't find it - should do something here to let user know an error has been made!!
+     else {   
+       // couldn't find it - should do something here 
+       // to let user know an error has been made!!
      }
    }
    return self ;
 }
 
--setEntityId: (int) theId {
+- setEntityId: (int)theId 
+{
   char *the_name ;  
-  boolId = theId;                                 // set the Boolean id
-  the_name = malloc(10) ;                         // create a name for each element
+  boolId = theId;                          // set the Boolean id
+  the_name = malloc(10) ;                  // create a name for each element
   sprintf(the_name, "Bool%d", theId) ;
 
   [self setNodeLabel: the_name];
@@ -59,7 +64,8 @@
 
 // create-time messages...
 
--placeX: (int) x Y: (int) y {
+- placeX: (int)x Y: (int)y 
+{
    // move to appropriate position on canvas...
    int currX, currY;
    int deltX, deltY;
@@ -81,38 +87,45 @@
    return self ;
 }
 
--createEnd {
+- createEnd 
+{
   [super createEnd] ;
   return self ;
 }
 
--(int) getBoolFunc {
+- (int)getBoolFunc 
+{
   return function;
 }
 
--setBoolNet: aBoolNet {
+- setBoolNet: aBoolNet 
+{
   boolNet = aBoolNet ;
   return self ;
 }
--(int) getPeriodicity {              // gets the periodicity of the node
+- (int)getPeriodicity 
+{              // gets the periodicity of the node
   return periodicity;
 }
 
--(const char *)getInstanceName {
+- (const char *)getInstanceName 
+{
   return label ;
 }
 
--(int) getInstanceNumber {
+- (int)getInstanceNumber 
+{
   return boolId;
 }
 
--(BOOL) getBoolState {  // get the Boolean state of the element
+- (BOOL)getBoolState 
+{  // get the Boolean state of the element
   return state[0];
 }
 
--displayNodeState {
+- displayNodeState {
   int attractor;  
-  attractor = [self updatePeriodicity];            // update the attractor type
+  attractor = [self updatePeriodicity];        // update the attractor type
  
   // colours the node according to state
   if (canvas) {        // if in "interactive" mode
@@ -158,7 +171,8 @@
   return self;
 }
 
--setBoolState: (BOOL) s {
+- setBoolState: (BOOL)s 
+{
   int i;
 
   // update the Boolean node's history...
@@ -169,11 +183,13 @@
   return self;
 }
 
--getInputLinks {
+- getInputLinks 
+{
   return fromList;
 }
 
--dropLinks {
+- dropLinks 
+{
   id  index, link;
 
   index = [fromList begin: globalZone];
@@ -189,7 +205,8 @@
   return self;
 }
 
--(int) getNumInputs {  
+- (int)getNumInputs 
+{  
   id  link, index, node;
   int numInputs = 0; 
 
@@ -206,7 +223,8 @@
   return numInputs;
 }
 
--(int) getNumOutputs {  
+- (int)getNumOutputs 
+{  
   id  link, index, node;
   int numOutputs = 0;
 
@@ -221,12 +239,14 @@
   return numOutputs;
 }
 
--stepRule {              // actual Boolean network behavoir
+- stepRule 
+{              // actual Boolean network behavoir
   id  link, index, node;
   BOOL inputState;
   int nodeNum;
-  int arrayIndex;       // index into the array to calculate the output of the Boolean function
-                            // this is converted from a K-tuple into a bit offset 
+  int arrayIndex;       
+  // index into the array to calculate the output of the Boolean function
+  // this is converted from a K-tuple into a bit offset 
 
   index = [fromList begin: globalZone] ;
   link = [index next];                 // get value of first input node
@@ -260,7 +280,8 @@
     
     // this part functions as a look-up table for the Boolean function
     // and the input K-tuple by using the bit offset arrayIndex 
-    // bit shift right by arrayIndex and bit-AND with one for the desired result
+    // bit shift right by arrayIndex and bit-AND with one for the 
+    // desired result
 
     newState = ( function >> arrayIndex & 1 );  // also set the new state 
                                                 //ready for the next transition
@@ -272,7 +293,8 @@
   return self;
 }
 
--(int) updatePeriodicity {  // classify attractor...
+- (int)updatePeriodicity 
+{  // classify attractor...
 
   int i;
   int p = 1;               // start looking for point attractors (period-1)
@@ -284,27 +306,29 @@
     i = 0;
     do {
       if (state[i] == state[i+p]) 
-	periodicity = p;         // period found! 
-                                 // continue looking until this period doesn't match
+	periodicity = p;   // period found! 
+                           // continue looking until this period doesn't match
       else
 	periodicity = -1;        // no match - exit loop
       i++;
     }
     while ( (i <= (2*MAX_PERIODICITY - p - 1)) && (periodicity != -1) );
-    p++;                         // periodicity must be greater... up the ante (so to speak!)
+    p++;           // periodicity must be greater... up the ante 
   }
   
-  if (periodicity == 1)          // 1-periodicity does not include a history all zeroes...
+  if (periodicity == 1)     // 1-periodicity does not 
+                            // include a history all zeroes...
     if (state[0] == 0)
       periodicity = 0;
   
   return periodicity;
 }
 
--update {     // updates the state of the node, synchronously
+- update 
+{     // updates the state of the node, synchronously
 
   [self setBoolState: newState];   // set myself into a new Boolean state
-  [self displayNodeState];         // performs the job of updating the "look of the node"
+  [self displayNodeState];         // update "look of the node"
 
   newState = 0;    // resets new State
   return self;
